@@ -28,24 +28,32 @@ from datetime import datetime, timedelta
 from fsm_pull import __version__
 from fsm_pull.connection import Connection
 
+
 def convert_date(date_string: str) -> str:
 
     if date_string == "now":
-        return (datetime.now() + timedelta(days=1)).strftime("%Y-%m-%d") + "T00:00:00+05:30"
+        return (datetime.now() + timedelta(days=1)).strftime(
+            "%Y-%m-%d"
+        ) + "T00:00:00+05:30"
 
     try:
 
         if len(date_string) == 8:
-            given_date = datetime.strptime(date_string, '%d%m%Y')
-            if datetime.strptime("01062016", "%d%m%Y") <= given_date <= \
-                    (datetime.now() + timedelta(days=1)):
-                return given_date.strftime('%Y-%m-%d') + "T00:00:00+05:30"
+            given_date = datetime.strptime(date_string, "%d%m%Y")
+            if (
+                datetime.strptime("01062016", "%d%m%Y")
+                <= given_date
+                <= (datetime.now() + timedelta(days=1))
+            ):
+                return given_date.strftime("%Y-%m-%d") + "T00:00:00+05:30"
 
         raise ValueError
 
     except ValueError:
-        raise ValueError("Please check date format and if date is in range,"
-                         "If date is 5th August 1947, Please enter 05081947(DDMMYYYY)")
+        raise ValueError(
+            "Please check date format and if date is in range,"
+            "If date is 5th August 1947, Please enter 05081947(DDMMYYYY)"
+        )
 
 
 def parse_metadata_json(conversations):
@@ -55,18 +63,26 @@ def parse_metadata_json(conversations):
     return conversations
 
 
-def get_call_list(org_id: int, lang_code: str, start: str, end: Optional[str] = "now",
-         call_quantity: Optional[int] = 0):
+def get_call_list(
+    org_id: int,
+    lang_code: str,
+    start: str,
+    end: str = "now",
+    call_quantity: int = 0,
+    flow_uuid: Optional[str] = None,
+):
     start = convert_date(start)
     end = convert_date(end)
 
     new_connection = Connection(org_id)
     proc_start_time = time.time()
-    print(f"Downloading {call_quantity if call_quantity else 'all'} Call(s) made between {start} and {end}")
+    print(
+        f"Downloading {call_quantity if call_quantity else 'all'} Call(s) made between {start} and {end}"
+    )
 
     call_list = []
 
-    for call in new_connection.fetch_calls(lang_code, start, end, call_quantity):
+    for call in new_connection.fetch_calls(lang_code, start, end, call_quantity, flow_uuid=flow_uuid):
         turns = new_connection.fetch_turns(call["uuid"])
         turns["conversations"] = parse_metadata_json(turns["conversations"])
 
@@ -81,13 +97,21 @@ def get_call_list(org_id: int, lang_code: str, start: str, end: Optional[str] =
     return call_list
 
 
-def pull(org_id: int, lang_code: str, start: str, end: Optional[str] = "now",
-         call_quantity: Optional[int] = 0, output_json: Optional[str] = ""):
+def pull(
+    org_id: int,
+    lang_code: str,
+    start: str,
+    end: str = "now",
+    call_quantity: int = 0,
+    output_json: Optional[str] = None,
+):
 
     if output_json and os.path.exists(output_json):
         raise FileExistsError(f"{output_json} already present")
 
-    call_list = get_call_list(org_id, lang_code, start, end=end, call_quantity=call_quantity)
+    call_list = get_call_list(
+        org_id, lang_code, start, end=end, call_quantity=call_quantity
+    )
 
     if output_json:
         print(f"Writing {len(call_list)} call(s) to {output_json}")
